@@ -98,8 +98,28 @@ class Keycloak:
         return payload
 
     def _build_name_role(self, role):
+        """
+
+        :param role:
+        :return:
+        """
         return self.client_id + "/" + role
 
+    def _token_info(self, token, method_token_info, **kwargs):
+        """
+
+        :param token:
+        :param method_token_info:
+        :param kwargs:
+        :return:
+        """
+        if method_token_info == 'introspect':
+            token_info = self.introspect(token)
+        else:
+            token_info = self.decode_token(token, **kwargs)
+
+        return token_info
+
     def well_know(self):
         """ The most important endpoint to understand is the well-known configuration
             endpoint. It lists endpoints and other configuration options relevant to
@@ -208,7 +228,7 @@ class Keycloak:
 
         return raise_error_from_response(data_raw, KeycloakGetError)
 
-    def instropect(self, token, rpt=None, token_type_hint=None):
+    def introspect(self, token, rpt=None, token_type_hint=None):
         """
         The introspection endpoint is used to retrieve the active state of a token. It is can only be
         invoked by confidential clients.
@@ -271,7 +291,7 @@ class Keycloak:
         self.authorization.load_config(authorization_json)
         authorization_file.close()
 
-    def get_policies(self, token):
+    def get_policies(self, token, method_token_info='introspect', **kwargs):
         """
         Get policies by user token
 
@@ -284,9 +304,9 @@ class Keycloak:
                 "Keycloak settings not found. Load Authorization Keycloak settings."
             )
 
-        token_info = self.instropect(token)
+        token_info = self._token_info(token, method_token_info, **kwargs)
 
-        if not token_info['active']:
+        if method_token_info == 'introspect' and not token_info['active']:
             raise KeycloakInvalidTokenError(
                 "Token expired or invalid."
             )
@@ -305,11 +325,13 @@ class Keycloak:
 
         return list(set(policies))
 
-    def get_permissions(self, token):
+    def get_permissions(self, token, method_token_info='introspect', **kwargs):
         """
         Get permission by user token
 
         :param token: user token
+        :param method_token_info: Decode token method
+        :param kwargs: parameters for decode
         :return: permissions list
         """
 
@@ -318,9 +340,9 @@ class Keycloak:
                 "Keycloak settings not found. Load Authorization Keycloak settings."
             )
 
-        token_info = self.instropect(token)
+        token_info = self._token_info(token, method_token_info, **kwargs)
 
-        if not token_info['active']:
+        if method_token_info == 'introspect' and not token_info['active']:
             raise KeycloakInvalidTokenError(
                 "Token expired or invalid."
             )
