@@ -48,26 +48,10 @@ class KeycloakOperationError(KeycloakError):
     pass
 
 
-class KeycloakListError(KeycloakOperationError):
-    pass
-
-
 class KeycloakGetError(KeycloakOperationError):
     pass
 
 
-class KeycloakCreateError(KeycloakOperationError):
-    pass
-
-
-class KeycloakUpdateError(KeycloakOperationError):
-    pass
-
-
-class KeycloakDeleteError(KeycloakOperationError):
-    pass
-
-
 class KeycloakSecretNotFound(KeycloakOperationError):
     pass
 
@@ -76,6 +60,14 @@ class KeycloakRPTNotFound(KeycloakOperationError):
     pass
 
 
+class KeycloakAuthorizationConfigError(KeycloakOperationError):
+    pass
+
+
+class KeycloakInvalidTokenError(KeycloakOperationError):
+    pass
+
+
 def raise_error_from_response(response, error, expected_code=200):
 
     if expected_code == response.status_code:
